@@ -34,38 +34,38 @@ admin.autodiscover()
 # Root URL patterns
 urlpatterns = patterns(
     '',
-    url(r'^$',
+    url(r'^{mount_point}$'.format(mount_point=settings.MOUNT_POINT),
         index,
         name='lava.home'),
-    url(r'^me/$',
+    url(r'^{mount_point}me/$'.format(mount_point=settings.MOUNT_POINT),
         me,
         name='lava.me'),
-    url(r'^version/$',
+    url(r'^{mount_point}version/$'.format(mount_point=settings.MOUNT_POINT),
         version,
         name='lava.version_details'),
-    url(r'^accounts/',
+    url(r'^{mount_point}accounts/'.format(mount_point=settings.MOUNT_POINT),
         include('django.contrib.auth.urls')),
-    url(r'^admin/',
+    url(r'^{mount_point}admin/'.format(mount_point=settings.MOUNT_POINT),
         include(admin.site.urls)),
-    url(r'^openid/',
+    url(r'^{mount_point}openid/'.format(mount_point=settings.MOUNT_POINT),
         include('django_openid_auth.urls')),
-    url(r'^RPC2/',
+    url(r'^{mount_point}RPC2/'.format(mount_point=settings.MOUNT_POINT),
         'linaro_django_xmlrpc.views.handler',
         name='lava.api_handler',
         kwargs={
             'mapper': loader.xmlrpc_mapper,
             'help_view': 'lava.api_help'}),
-    url(r'^api/help/$',
+    url(r'^{mount_point}api/help/$'.format(mount_point=settings.MOUNT_POINT),
         'linaro_django_xmlrpc.views.help',
         name='lava.api_help',
         kwargs={
             'mapper': loader.xmlrpc_mapper}),
-    url(r'^api/',
+    url(r'^{mount_point}api/'.format(mount_point=settings.MOUNT_POINT),
         include(api_urls.token_urlpatterns)),
     # XXX: This is not needed but without it linaro-django-xmlrpc tests fail
-    url(r'^api/',
+    url(r'^{mount_point}api/'.format(mount_point=settings.MOUNT_POINT),
         include(api_urls.default_mapper_urlpatterns)),
-    url(r'^utils/markitup/',
+    url(r'^{mount_point}utils/markitup/'.format(mount_point=settings.MOUNT_POINT),
         include('lava_markitup.urls')))
 
 
